@@ -15,7 +15,7 @@ SEXP mcmc_new(SEXP Y, SEXP X, SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim,
 	int pivot = LOGICAL(Rpivot)[0];
 	double tol = REAL(Rtol)[0];
 
-	//  Rprintf("Allocating Space for %d Models\n", nModels) ;
+  // Rprintf("Allocating Space for %d Models\n", nModels) ;
 	SEXP ANS = PROTECT(allocVector(VECSXP, 16)); ++nProtected;
 	SEXP ANS_names = PROTECT(allocVector(STRSXP, 16)); ++nProtected;
 	SEXP Rprobs = PROTECT(duplicate(Rprobinit)); ++nProtected;
@@ -35,6 +35,34 @@ SEXP mcmc_new(SEXP Y, SEXP X, SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim,
 	SEXP sampleprobs = PROTECT(allocVector(REALSXP, nModels)); ++nProtected;
 	SEXP NumUnique = PROTECT(allocVector(INTSXP, 1)); ++nProtected;
 
+	PROTECT_INDEX counts_idx;
+	PROTECT_WITH_INDEX(counts, &counts_idx);
+	PROTECT_INDEX R2_idx;
+	PROTECT_WITH_INDEX(R2, &R2_idx);
+	PROTECT_INDEX shrinkage_idx;
+	PROTECT_WITH_INDEX(shrinkage, &shrinkage_idx);
+	PROTECT_INDEX modelspace_idx;
+	PROTECT_WITH_INDEX(modelspace, &modelspace_idx);
+	PROTECT_INDEX modeldim_idx;
+	PROTECT_WITH_INDEX(modeldim, &modeldim_idx);
+	PROTECT_INDEX rank_idx;
+	PROTECT_WITH_INDEX(rank, &rank_idx);
+	PROTECT_INDEX beta_idx;
+	PROTECT_WITH_INDEX(beta, &beta_idx);
+	PROTECT_INDEX se_idx;
+	PROTECT_WITH_INDEX(se, &se_idx);
+	PROTECT_INDEX mse_idx;
+	PROTECT_WITH_INDEX(mse, &mse_idx);
+	PROTECT_INDEX modelprobs_idx;
+	PROTECT_WITH_INDEX(modelprobs, &modelprobs_idx);
+	PROTECT_INDEX priorprobs_idx;
+	PROTECT_WITH_INDEX(priorprobs, &priorprobs_idx);
+	PROTECT_INDEX logmarg_idx;
+	PROTECT_WITH_INDEX(logmarg, &logmarg_idx);
+	PROTECT_INDEX sampleprobs_idx;
+	PROTECT_WITH_INDEX(sampleprobs, &sampleprobs_idx);
+	
+
 	double *Xwork, *Ywork,*wts, *probs, shrinkage_m,
 		mse_m, MH=0.0, prior_m=1.0,
 		R2_m, RSquareFull, logmargy, postold, postnew;
@@ -135,7 +163,7 @@ SEXP mcmc_new(SEXP Y, SEXP X, SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim,
 	double problocal = REAL(plocal)[0];
 	
 	
-	while (nUnique < k && m < INTEGER(BURNIN_Iterations)[0]) {
+	while (nUnique < k && m < (INTEGER(MCMC_Iterations)[0] + INTEGER(BURNIN_Iterations)[0])) {
 
 	  memcpy(model, modelold, sizeof(int)*p);
 		pmodel =  n_sure;
@@ -190,7 +218,7 @@ SEXP mcmc_new(SEXP Y, SEXP X, SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim,
 		//    Rprintf("MH new %lf old %lf\n", postnew, postold);
 		if (unif_rand() < MH) {
 		  if (newmodel == 1) {
-		    if ((m % thin) == 0 )  {
+		    if (m % thin == 0 )  {
 
 		    new_loc = nUnique;
 		    insert_model_tree(tree, vars, n, model, nUnique);
@@ -247,19 +275,22 @@ SEXP mcmc_new(SEXP Y, SEXP X, SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim,
 	SET_STRING_ELT(ANS_names, 0, mkChar("probne0"));
 
 	if (nUnique < nModels) {
-	  SETLENGTH(modelspace, nUnique);
-	  SETLENGTH(logmarg, nUnique);
-	  SETLENGTH(modelprobs, nUnique);
-	  SETLENGTH(priorprobs, nUnique);
-	  SETLENGTH(sampleprobs, nUnique);
-	  SETLENGTH(counts, nUnique);
-	  SETLENGTH(beta, nUnique);
-	  SETLENGTH(se, nUnique);
-	  SETLENGTH(mse, nUnique);
-	  SETLENGTH(shrinkage, nUnique);
-	  SETLENGTH(modeldim, nUnique);
-	  SETLENGTH(R2, nUnique);
-	  SETLENGTH(rank, nUnique);
+	  nModels = nUnique;
+	  REPROTECT(counts= Rf_lengthgets(counts, nUnique), counts_idx);
+	  REPROTECT(logmarg= Rf_lengthgets(logmarg, nUnique), logmarg_idx);
+	  REPROTECT(modelprobs= Rf_lengthgets(modelprobs, nUnique), modelprobs_idx);
+	  REPROTECT(priorprobs= Rf_lengthgets(priorprobs, nUnique), priorprobs_idx);
+	  REPROTECT(sampleprobs= Rf_lengthgets(sampleprobs, nUnique), sampleprobs_idx);
+	  REPROTECT(mse = Rf_lengthgets(mse, nUnique), mse_idx);
+	  REPROTECT(shrinkage = Rf_lengthgets(shrinkage, nUnique), shrinkage_idx);
+	  REPROTECT(modeldim= Rf_lengthgets(modeldim, nUnique), modeldim_idx);
+	  REPROTECT(R2= Rf_lengthgets(R2, nUnique), R2_idx);
+	  REPROTECT(se= Rf_lengthgets(se, nUnique), se_idx);
+	  REPROTECT(rank = Rf_lengthgets(rank, nUnique), rank_idx);
+	  REPROTECT(modelspace = Rf_lengthgets(modelspace, nUnique), modelspace_idx);
+	  REPROTECT(beta = Rf_lengthgets(beta, nUnique), beta_idx);
+	  REPROTECT(se= Rf_lengthgets(se, nUnique), se_idx);
+	  
 	}
 	SET_VECTOR_ELT(ANS, 1, modelspace);
 	SET_STRING_ELT(ANS_names, 1, mkChar("which"));
